@@ -440,19 +440,25 @@ void InputFilter::parseClientCommand(const QString &prefix, const QString &comma
             }
             else if (ctcpCommand=="clientinfo" && !isChan)
             {
-                server->appendMessageToFrontmost(i18n("CTCP"),
-                    i18n("Received CTCP-%1 request from %2, sending answer.",
-                         QString::fromLatin1("CLIENTINFO"), sourceNick)
-                    );
-                server->ctcpReply(sourceNick,QString("CLIENTINFO ACTION CLIENTINFO DCC PING TIME VERSION"));
+                if (!isIgnore(prefix, Ignore::CTCP))
+                {
+                    server->appendMessageToFrontmost(i18n("CTCP"),
+                        i18n("Received CTCP-%1 request from %2, sending answer.",
+                            QString::fromLatin1("CLIENTINFO"), sourceNick)
+                        );
+                    server->ctcpReply(sourceNick,QString("CLIENTINFO ACTION CLIENTINFO DCC PING TIME VERSION"));
+                }
             }
             else if (ctcpCommand=="time" && !isChan)
             {
-                server->appendMessageToFrontmost(i18n("CTCP"),
-                    i18n("Received CTCP-%1 request from %2, sending answer.",
-                         QString::fromLatin1("TIME"), sourceNick)
-                    );
-                server->ctcpReply(sourceNick,QString("TIME ")+QDateTime::currentDateTime().toString());
+                if (!isIgnore(prefix, Ignore::CTCP))
+                {
+                    server->appendMessageToFrontmost(i18n("CTCP"),
+                        i18n("Received CTCP-%1 request from %2, sending answer.",
+                            QString::fromLatin1("TIME"), sourceNick)
+                        );
+                    server->ctcpReply(sourceNick,QString("TIME ")+QDateTime::currentDateTime().toString());
+                }
             }
 
             // No known CTCP request, give a general message
@@ -514,10 +520,7 @@ void InputFilter::parseClientCommand(const QString &prefix, const QString &comma
                         int dateArrived=QDateTime::currentDateTime().toTime_t();
                         int dateSent=reply.toInt();
                         int time = dateArrived-dateSent;
-                        QString unit = "seconds";
-
-                        if (time==1)
-                            unit = "second";
+                        QString unit = i18np("second", "seconds", time);
 
                         server->appendMessageToFrontmost(i18n("CTCP"),
                             i18n("Received CTCP-PING reply from %1: %2 %3.",
@@ -620,8 +623,6 @@ void InputFilter::parseClientCommand(const QString &prefix, const QString &comma
             // Join the channel
             server->joinChannel(channelName, sourceHostmask);
 
-            server->resetNickList(channelName);
-
             // Upon JOIN we're going to receive some NAMES input from the server which
             // we need to be able to tell apart from manual invocations of /names
             setAutomaticRequest("NAMES",channelName,true);
