@@ -71,7 +71,7 @@ Query::Query(QWidget* parent, QString _name) : ChatWindow(parent)
     m_headerSplitter->setStretchFactor(m_headerSplitter->indexOf(ircBox), 1);
     setTextView(ircBox->ircView());               // Server will be set later in setServer();
     textView->setAcceptDrops(true);
-    connect(textView,SIGNAL(filesDropped(const QStringList&)),this,SLOT(filesDropped(const QStringList&)));
+    connect(textView,SIGNAL(urlsDropped(const KUrl::List)),this,SLOT(urlsDropped(const KUrl::List)));
     connect(textView,SIGNAL(popupCommand(int)),this,SLOT(popup(int)));
 
     // link "Whois", "Ignore" ... menu items into ircview popup
@@ -294,37 +294,6 @@ void Query::sendQueryText(const QString& sendLine)
     } // for
 }
 
-void Query::updateAppearance()
-{
-    QColor fg, bg;
-
-    if (Preferences::self()->inputFieldsBackgroundColor())
-    {
-        fg = Preferences::self()->color(Preferences::ChannelMessage);
-        bg = Preferences::self()->color(Preferences::TextViewBackground);
-    }
-    else
-    {
-        fg = palette().windowText().color();
-        bg = palette().base().color();
-    }
-
-    QPalette queryInputPalette(queryInput->palette());
-    queryInputPalette.setColor(QPalette::WindowText, fg);
-    queryInputPalette.setColor(QPalette::Text, fg);
-    queryInputPalette.setColor(QPalette::Base, bg);
-
-    queryInput->setPalette(queryInputPalette);
-
-
-    if (Preferences::self()->customTextFont())
-        queryInput->setFont(Preferences::self()->textFont());
-    else
-        queryInput->setFont(KGlobalSettings::generalFont());
-
-    ChatWindow::updateAppearance();
-}
-
 void Query::textPasted(const QString& text)
 {
     if(m_server)
@@ -640,9 +609,9 @@ void Query::closeWithoutAsking()
     m_server->removeQuery(this);
 }
 
-void Query::filesDropped(const QStringList& files)
+void Query::urlsDropped(const KUrl::List urls)
 {
-    m_server->sendURIs(files, getName());
+    m_server->sendURIs(urls, getName());
 }
 
 void Query::serverOnline(bool online)
