@@ -26,7 +26,7 @@
 #include "notificationhandler.h"
 #include "irccharsets.h"
 #include "connectionmanager.h"
-#include "awaymanager.h"
+#include "abstractawaymanager.h"
 #include "transfermanager.h"
 
 
@@ -268,13 +268,20 @@ MainWindow::MainWindow() : KXmlGuiWindow(0)
     connect(action, SIGNAL(triggered()), m_viewContainer, SLOT(closeCurrentView()));
     actionCollection()->addAction("close_tab", action);
 
+    action=new KAction(this);
+    action->setText(i18n("Last Focused Tab"));
+    action->setShortcut(KShortcut("Alt+Space"));
+    action->setEnabled(false);
+    connect(action, SIGNAL(triggered()), m_viewContainer, SLOT(showLastFocusedView()));
+    actionCollection()->addAction("last_focused_tab", action);
+    
     action=new KAction(this);
     action->setText(i18n("Next Active Tab"));
     action->setShortcut(KShortcut("Ctrl+Alt+Space"));
     action->setEnabled(false);
     connect(action, SIGNAL(triggered()), m_viewContainer, SLOT(showNextActiveView()));
     actionCollection()->addAction("next_active_tab", action);
-
+    
     if (Preferences::self()->tabPlacement()==Preferences::Left)
     {
         action=new KAction(this);
@@ -415,16 +422,12 @@ MainWindow::MainWindow() : KXmlGuiWindow(0)
     awayAction->setShortcut(KShortcut("Ctrl+Shift+A"));
     awayAction->setEnabled(false);
     awayAction->setIcon(KIcon("im-user-away"));
-    connect(awayAction, SIGNAL(triggered(bool)), Application::instance()->getAwayManager(), SLOT(toggleGlobalAway(bool)));
+    connect(awayAction, SIGNAL(triggered(bool)), Application::instance()->getAwayManager(), SLOT(setGlobalAway(bool)));
     actionCollection()->addAction("toggle_away", awayAction);
 
     action=new KAction(this);
     action->setText(i18n("&Join Channel..."));
-#if KDE_IS_VERSION(4,2,85)
     action->setIcon(KIcon("irc-join-channel"));
-#else
-    action->setIcon(KIcon("list-add"));
-#endif
     action->setShortcut(KShortcut("Ctrl+J"));
     action->setEnabled(false);
     action->setStatusTip("Join a new channel on this server");
