@@ -37,12 +37,6 @@ namespace Konversation
     {
     }
 
-    QString cleanMessage(QString message)
-    {
-        QString s = Qt::escape(Konversation::removeIrcMarkup(message));
-        return s;
-    }
-
     void NotificationHandler::message(ChatWindow* chatWin, const QString& fromNick, const QString& message)
     {
         if (!chatWin || !chatWin->notificationsEnabled())
@@ -51,10 +45,10 @@ namespace Konversation
         if (Preferences::self()->disableNotifyWhileAway() && chatWin->getServer() && chatWin->getServer()->isAway())
             return;
 
-        QString cleanedMessage = cleanMessage(message);
-        QString cutup = addLineBreaks(cleanedMessage);
+        QString cleanedMessage = removeIrcMarkup(message);
+        QString forKNotify = Qt::escape(cleanedMessage);
 
-        KNotification::event(QString::fromLatin1("message"), QString("<qt>&lt;%1&gt; %2</qt>").arg(fromNick).arg(cutup), QPixmap(), m_mainWindow);
+        KNotification::event(QString::fromLatin1("message"), QString("<html>&lt;%1&gt; %2</html>").arg(fromNick).arg(forKNotify), QPixmap(), m_mainWindow);
 
         if(!Preferences::self()->trayNotifyOnlyOwnNick())
         {
@@ -79,10 +73,10 @@ namespace Konversation
         if (Preferences::self()->disableNotifyWhileAway() && chatWin->getServer() && chatWin->getServer()->isAway())
             return;
 
-        QString cleanedMessage = cleanMessage(message);
-        QString cutup = addLineBreaks(cleanedMessage);
+        QString cleanedMessage = removeIrcMarkup(message);
+        QString forKNotify = Qt::escape(cleanedMessage);
 
-        KNotification::event(QString::fromLatin1("nick"), QString("<qt>&lt;%1&gt; %2</qt>").arg(fromNick).arg(cutup), QPixmap(), m_mainWindow);
+        KNotification::event(QString::fromLatin1("nick"), QString("<html>&lt;%1&gt; %2</html>").arg(fromNick).arg(forKNotify), QPixmap(), m_mainWindow);
 
         startTrayNotification(chatWin);
 
@@ -105,10 +99,10 @@ namespace Konversation
         if (Preferences::self()->disableNotifyWhileAway() && chatWin->getServer() && chatWin->getServer()->isAway())
             return;
 
-        QString cleanedMessage = cleanMessage(message);
-        QString cutup = addLineBreaks(cleanedMessage);
+        QString cleanedMessage = removeIrcMarkup(message);
+        QString forKNotify = Qt::escape(cleanedMessage);
 
-        KNotification::event(QString::fromLatin1("queryMessage"), QString("<qt>&lt;%1&gt; %2</qt>").arg(fromNick).arg(cutup), QPixmap(), m_mainWindow);
+        KNotification::event(QString::fromLatin1("queryMessage"), QString("<html>&lt;%1&gt; %2</html>").arg(fromNick).arg(forKNotify), QPixmap(), m_mainWindow);
 
         startTrayNotification(chatWin);
 
@@ -320,13 +314,13 @@ namespace Konversation
 
         startTrayNotification(chatWin);
 
-        QString cleanedMessage = cleanMessage(message);
-        QString cutup = addLineBreaks(cleanedMessage);
+        QString cleanedMessage = removeIrcMarkup(message);
+        QString forKNotify = Qt::escape(cleanedMessage);
 
         if(fromNick.isEmpty())
-            KNotification::event(QString::fromLatin1("highlight"), QString("<qt>(%1) *** %2</qt>").arg(chatWin->getName()).arg(cutup), QPixmap(), m_mainWindow);
+            KNotification::event(QString::fromLatin1("highlight"), QString("<html>(%1) *** %2</html>").arg(chatWin->getName()).arg(forKNotify), QPixmap(), m_mainWindow);
         else
-            KNotification::event(QString::fromLatin1("highlight"), QString("<qt>(%1) &lt;%2&gt; %3</qt>").arg(chatWin->getName()).arg(fromNick).arg(cutup), QPixmap(), m_mainWindow);
+            KNotification::event(QString::fromLatin1("highlight"), QString("<html>(%1) &lt;%2&gt; %3</html>").arg(chatWin->getName()).arg(fromNick).arg(forKNotify), QPixmap(), m_mainWindow);
 
         if(Preferences::self()->oSDShowOwnNick() &&
             (!m_mainWindow->isActiveWindow() || (chatWin != m_mainWindow->getViewContainer()->getFrontView())))
@@ -335,10 +329,10 @@ namespace Konversation
             // if there was no nick associated, this must be a command message, so don't try displaying
             // an empty nick in <>
             if(fromNick.isEmpty())
-                konvApp->osd->show(i18n("[HighLight] (%1) *** %2",chatWin->getName(),message));
+                konvApp->osd->show(i18n("[HighLight] (%1) *** %2",chatWin->getName(),cleanedMessage));
             // normal highlight message
             else
-                konvApp->osd->show(i18n("[HighLight] (%1) &lt;%2&gt; %3",chatWin->getName(),fromNick,message));
+                konvApp->osd->show(i18n("[HighLight] (%1) &lt;%2&gt; %3",chatWin->getName(),fromNick,cleanedMessage));
         }
     }
 
@@ -364,20 +358,6 @@ namespace Konversation
         KNotification::event(QString::fromLatin1("channelJoin"), i18n("You have joined %1.",channel), QPixmap(), m_mainWindow);
     }
 
-    QString NotificationHandler::addLineBreaks(const QString& string)
-    {
-        QString cutup = string;
-        int offset = 0;
-
-        for(int i = 0; i < string.length(); i += 50)
-        {
-            cutup.insert(i + (offset * 4), "<br>");
-            ++offset;
-        }
-
-        return cutup;
-    }
-
 }
 
 #include "notificationhandler.moc"
