@@ -67,9 +67,7 @@ IRCInput::IRCInput(QWidget* parent) : KTextEdit(parent)
 
     document()->adjustSize();
 
-#if QT_VERSION >= 0x040500
     document()->setDocumentMargin(2);
-#endif
 }
 
 IRCInput::~IRCInput()
@@ -158,6 +156,21 @@ void IRCInput::slotSpellCheckDone(const QString& s)
 
 void IRCInput::updateAppearance()
 {
+    QPalette palette;
+
+    if (Preferences::self()->inputFieldsBackgroundColor())
+    {
+        palette.setColor(QPalette::Text, Preferences::self()->color(Preferences::ChannelMessage));
+        palette.setColor(QPalette::Base, Preferences::self()->color(Preferences::TextViewBackground));
+    }
+
+    setPalette(palette);
+
+    if (Preferences::self()->customTextFont())
+        setFont(Preferences::self()->textFont());
+    else
+        setFont(KGlobalSettings::generalFont());
+
     m_multiRow = Preferences::self()->useMultiRowInputBox();
     setLineWrapMode(m_multiRow ? WidgetWidth : NoWrap);
 
